@@ -1,22 +1,6 @@
 /* This file is part of Spectacle, the KDE screenshot utility
- * Copyright 2019 David Redondo <kde@david-redondo.de>
- * Copyright (C) 2015 Boudhayan Gupta <bgupta@kde.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
+ * SPDX-FileCopyrightText: 2019 David Redondo <kde@david-redondo.de>
+ * SPDX-FileCopyrightText: 2015 Boudhayan Gupta <bgupta@kde.org>
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
@@ -25,37 +9,38 @@
 #include "settings.h"
 #include <kio_version.h>
 
-#include <QDir>
-#include <QMimeData>
-#include <QMimeDatabase>
-#include <QImageWriter>
-#include <QTemporaryDir>
-#include <QTemporaryFile>
 #include <QApplication>
 #include <QClipboard>
-#include <QPainter>
+#include <QDir>
 #include <QFileDialog>
+#include <QImageWriter>
+#include <QMimeData>
+#include <QMimeDatabase>
+#include <QPainter>
+#include <QPrinter>
+#include <QRandomGenerator>
 #include <QRegularExpression>
 #include <QRegularExpressionMatch>
 #include <QString>
-#include <QRandomGenerator>
+#include <QTemporaryDir>
+#include <QTemporaryFile>
 
-#include <KSharedConfig>
+#include <KIO/FileCopyJob>
 #include <KIO/ListJob>
 #include <KIO/MkpathJob>
-#include <KIO/FileCopyJob>
 #include <KIO/StatJob>
 #include <KRecentDocument>
+#include <KSharedConfig>
+#include <KSystemClipboard>
 
-
-
-ExportManager::ExportManager(QObject *parent) :
-    QObject(parent),
-    mSavePixmap(QPixmap()),
-    mTempFile(QUrl()),
-    mTempDir(nullptr)
+ExportManager::ExportManager(QObject *parent)
+    : QObject(parent)
+    , mImageSavedNotInTemp(false)
+    , mSavePixmap(QPixmap())
+    , mTempFile(QUrl())
 {
     connect(this, &ExportManager::imageSaved, &Settings::setLastSaveLocation);
+    connect(this, &ExportManager::imageSavedAndCopied, &Settings::setLastSaveLocation);
 }
 
 ExportManager::~ExportManager()
@@ -63,9 +48,11 @@ ExportManager::~ExportManager()
     delete mTempDir;
 }
 
-ExportManager* ExportManager::instance()
+ExportManager *ExportManager::instance()
 {
     static ExportManager instance;
+    // Ensure the SystemClipboard is instantiated early enough
+    KSystemClipboard::instance();
     return &instance;
 }
 
@@ -107,11 +94,14 @@ void ExportManager::setPixmap(const QPixmap &pixmap)
         file.remove();
         mTempFile = QUrl();
     }
+
+    // since the pixmap was modified, we now consider the image unsaved
+    mImageSavedNotInTemp = false;
 }
 
 void ExportManager::updatePixmapTimestamp()
 {
-	mPixmapTimestamp = QDateTime::currentDateTime();
+    mPixmapTimestamp = QDateTime::currentDateTime();
 }
 
 void ExportManager::setTimestamp(const QDateTime &timestamp)
@@ -140,9 +130,8 @@ QUrl ExportManager::getAutosaveFilename()
     const QString baseDir = defaultSaveLocation();
     const QDir baseDirPath(baseDir);
     const QString filename = makeAutosaveFilename();
-    const QString fullpath = autoIncrementFilename(baseDirPath.filePath(filename),
-                                                   Settings::self()->defaultSaveImageFormat().toLower(),
-                                                   &ExportManager::isFileExists);
+    const QString fullpath =
+        autoIncrementFilename(baseDirPath.filePath(filename), Settings::self()->defaultSaveImageFormat().toLower(), &ExportManager::isFileExists);
 
     const QUrl fileNameUrl = QUrl::fromUserInput(fullpath);
     if (fileNameUrl.isValid()) {
@@ -156,8 +145,8 @@ QString ExportManager::truncatedFilename(QString const &filename)
 {
     QString result = filename;
     constexpr auto maxFilenameLength = 255;
-    constexpr auto maxExtensionLength = 5;  // For example, ".jpeg"
-    constexpr auto maxCounterLength = 20;  // std::numeric_limits<quint64>::max() == 18446744073709551615
+    constexpr auto maxExtensionLength = 5; // For example, ".jpeg"
+    constexpr auto maxCounterLength = 20; // std::numeric_limits<quint64>::max() == 18446744073709551615
     constexpr auto maxLength = maxFilenameLength - maxCounterLength - maxExtensionLength;
     result.truncate(maxLength);
     return result;
@@ -175,10 +164,9 @@ QString ExportManager::formatFilename(const QString &nameTemplate)
     QString baseDir = defaultSaveLocation();
     QString title;
 
-    if (mCaptureMode == Spectacle::CaptureMode::ActiveWindow ||
-        mCaptureMode == Spectacle::CaptureMode::TransientWithParent ||
-        mCaptureMode == Spectacle::CaptureMode::WindowUnderCursor) {
-        title = mWindowTitle.replace(QLatin1Char('/'), QLatin1String("_"));  // POSIX doesn't allow "/" in filenames
+    if (mCaptureMode == Spectacle::CaptureMode::ActiveWindow || mCaptureMode == Spectacle::CaptureMode::TransientWithParent
+        || mCaptureMode == Spectacle::CaptureMode::WindowUnderCursor) {
+        title = mWindowTitle.replace(QLatin1Char('/'), QLatin1String("_")); // POSIX doesn't allow "/" in filenames
     } else {
         // Remove '%T' with separators around it
         const auto wordSymbol = QStringLiteral(R"(\p{L}\p{M}\p{N})");
@@ -188,13 +176,14 @@ QString ExportManager::formatFilename(const QString &nameTemplate)
     }
 
     QString result = baseName.replace(QLatin1String("%Y"), timestamp.toString(QStringLiteral("yyyy")))
-                             .replace(QLatin1String("%y"), timestamp.toString(QStringLiteral("yy")))
-                             .replace(QLatin1String("%M"), timestamp.toString(QStringLiteral("MM")))
-                             .replace(QLatin1String("%D"), timestamp.toString(QStringLiteral("dd")))
-                             .replace(QLatin1String("%H"), timestamp.toString(QStringLiteral("hh")))
-                             .replace(QLatin1String("%m"), timestamp.toString(QStringLiteral("mm")))
-                             .replace(QLatin1String("%S"), timestamp.toString(QStringLiteral("ss")))
-                             .replace(QLatin1String("%T"), title);
+                         .replace(QLatin1String("%y"), timestamp.toString(QStringLiteral("yy")))
+                         .replace(QLatin1String("%M"), timestamp.toString(QStringLiteral("MM")))
+                         .replace(QLatin1String("%D"), timestamp.toString(QStringLiteral("dd")))
+                         .replace(QLatin1String("%H"), timestamp.toString(QStringLiteral("hh")))
+                         .replace(QLatin1String("%m"), timestamp.toString(QStringLiteral("mm")))
+                         .replace(QLatin1String("%S"), timestamp.toString(QStringLiteral("ss")))
+                         .replace(QLatin1String("%t"), timestamp.toString(QStringLiteral("t")))
+                         .replace(QLatin1String("%T"), title);
 
     // check if basename includes %[N]d token for sequential file numbering
     QRegularExpression paddingRE;
@@ -208,7 +197,7 @@ QString ExportManager::formatFilename(const QString &nameTemplate)
         while (it.hasNext()) {
             QRegularExpressionMatch paddingMatch = it.next();
             matches.push_back(paddingMatch);
-            //determine padding value
+            // determine padding value
             int paddedLength = 1;
             if (!paddingMatch.captured(1).isEmpty()) {
                 paddedLength = paddingMatch.captured(1).toInt();
@@ -217,10 +206,10 @@ QString ExportManager::formatFilename(const QString &nameTemplate)
             resultCopy.replace(escapedMatch, QStringLiteral("(\\d{%1,})").arg(QString::number(paddedLength)));
         }
         if (result.contains(QLatin1Char('/'))) {
-          // In case the filename template contains a subdirectory,
-          // we need to search for files in the subdirectory instead of the baseDir.
-          // so let's add that to baseDir before we search for files.
-          baseDir += QStringLiteral("/%1").arg(result.section(QLatin1Char('/'), 0, -2));
+            // In case the filename template contains a subdirectory,
+            // we need to search for files in the subdirectory instead of the baseDir.
+            // so let's add that to baseDir before we search for files.
+            baseDir += QStringLiteral("/%1").arg(result.section(QLatin1Char('/'), 0, -2));
         }
         // search save directory for files
         QDir dir(baseDir);
@@ -236,7 +225,7 @@ QString ExportManager::formatFilename(const QString &nameTemplate)
             // if there are files in the directory that look like the file name with sequential numbering
             if (filteredFiles.length() > 0) {
                 // loop through filtered file names looking for highest number
-                for (const QString &filteredFile: filteredFiles) {
+                for (const QString &filteredFile : filteredFiles) {
                     int currentFileNumber = fileNumberRE.match(filteredFile).captured(1).toInt();
                     if (currentFileNumber > highestFileNumber) {
                         highestFileNumber = currentFileNumber;
@@ -245,7 +234,7 @@ QString ExportManager::formatFilename(const QString &nameTemplate)
             }
         }
         // replace placeholder with next number padded
-        for (const auto& match : matches) {
+        for (const auto &match : matches) {
             int paddedLength = 1;
             if (!match.captured(1).isEmpty()) {
                 paddedLength = match.captured(1).toInt();
@@ -269,8 +258,7 @@ QString ExportManager::formatFilename(const QString &nameTemplate)
     return truncatedFilename(result);
 }
 
-QString ExportManager::autoIncrementFilename(const QString &baseName, const QString &extension,
-                                             FileNameAlreadyUsedCheck isFileNameUsed)
+QString ExportManager::autoIncrementFilename(const QString &baseName, const QString &extension, FileNameAlreadyUsedCheck isFileNameUsed)
 {
     QString result = truncatedFilename(baseName) + QLatin1String(".") + extension;
     if (!((this->*isFileNameUsed)(QUrl::fromUserInput(result)))) {
@@ -295,7 +283,7 @@ QString ExportManager::autoIncrementFilename(const QString &baseName, const QStr
 QString ExportManager::makeSaveMimetype(const QUrl &url)
 {
     QMimeDatabase mimedb;
-    QString type = mimedb.mimeTypeForUrl(url).preferredSuffix();
+    const QString type = mimedb.mimeTypeForUrl(url).preferredSuffix();
 
     if (type.isEmpty()) {
         return Settings::self()->defaultSaveImageFormat().toLower();
@@ -317,7 +305,7 @@ bool ExportManager::writeImage(QIODevice *device, const QByteArray &format)
         imageWriter.setCompression(50);
     }
     if (!(imageWriter.canWrite())) {
-        emit errorMessage(i18n("QImageWriter cannot write image: %1", imageWriter.errorString()));
+        Q_EMIT errorMessage(i18n("QImageWriter cannot write image: %1", imageWriter.errorString()));
         return false;
     }
 
@@ -331,18 +319,18 @@ bool ExportManager::localSave(const QUrl &url, const QString &mimetype)
     const QDir dir(dirPath.path());
 
     if (!dir.mkpath(QStringLiteral("."))) {
-        emit errorMessage(xi18nc("@info",
-                                 "Cannot save screenshot because creating "
-                                 "the directory failed:<nl/><filename>%1</filename>",
-                                 dirPath.path()));
+        Q_EMIT errorMessage(xi18nc("@info",
+                                   "Cannot save screenshot because creating "
+                                   "the directory failed:<nl/><filename>%1</filename>",
+                                   dirPath.path()));
         return false;
     }
 
     QFile outputFile(url.toLocalFile());
 
     outputFile.open(QFile::WriteOnly);
-    if(!writeImage(&outputFile, mimetype.toLatin1())) {
-        emit errorMessage(i18n("Cannot save screenshot. Error while writing file."));
+    if (!writeImage(&outputFile, mimetype.toLatin1())) {
+        Q_EMIT errorMessage(i18n("Cannot save screenshot. Error while writing file."));
         return false;
     }
     return true;
@@ -350,7 +338,6 @@ bool ExportManager::localSave(const QUrl &url, const QString &mimetype)
 
 bool ExportManager::remoteSave(const QUrl &url, const QString &mimetype)
 {
-
     // Check if remote save directory exists
     const QUrl dirPath(url.adjusted(QUrl::RemoveFilename));
     KIO::ListJob *listJob = KIO::listDir(dirPath);
@@ -362,10 +349,10 @@ bool ExportManager::remoteSave(const QUrl &url, const QString &mimetype)
         mkpathJob->exec();
 
         if (mkpathJob->error() != KJob::NoError) {
-            emit errorMessage(xi18nc("@info",
-                                     "Cannot save screenshot because creating the "
-                                     "remote directory failed:<nl/><filename>%1</filename>",
-                                     dirPath.path()));
+            Q_EMIT errorMessage(xi18nc("@info",
+                                       "Cannot save screenshot because creating the "
+                                       "remote directory failed:<nl/><filename>%1</filename>",
+                                       dirPath.path()));
             return false;
         }
     }
@@ -373,8 +360,8 @@ bool ExportManager::remoteSave(const QUrl &url, const QString &mimetype)
     QTemporaryFile tmpFile;
 
     if (tmpFile.open()) {
-        if(!writeImage(&tmpFile, mimetype.toLatin1())) {
-            emit errorMessage(i18n("Cannot save screenshot. Error while writing temporary local file."));
+        if (!writeImage(&tmpFile, mimetype.toLatin1())) {
+            Q_EMIT errorMessage(i18n("Cannot save screenshot. Error while writing temporary local file."));
             return false;
         }
 
@@ -382,7 +369,7 @@ bool ExportManager::remoteSave(const QUrl &url, const QString &mimetype)
         uploadJob->exec();
 
         if (uploadJob->error() != KJob::NoError) {
-            emit errorMessage(i18n("Unable to save image. Could not upload file to remote location."));
+            Q_EMIT errorMessage(i18n("Unable to save image. Could not upload file to remote location."));
             return false;
         }
         return true;
@@ -408,15 +395,13 @@ QUrl ExportManager::tempSave()
         // supports the use-case of creating multiple screenshots in a row
         // and exporting them to the same destination e.g. via clipboard,
         // where the temp file name is used as filename suggestion
-        const QString baseFileName = mTempDir->path() + QLatin1Char('/') +
-                                     QUrl::fromLocalFile(makeAutosaveFilename()).fileName();
+        const QString baseFileName = mTempDir->path() + QLatin1Char('/') + QUrl::fromLocalFile(makeAutosaveFilename()).fileName();
 
         QString mimetype = makeSaveMimetype(QUrl(baseFileName));
-        const QString fileName = autoIncrementFilename(baseFileName, mimetype,
-                                                       &ExportManager::isTempFileAlreadyUsed);
+        const QString fileName = autoIncrementFilename(baseFileName, mimetype, &ExportManager::isTempFileAlreadyUsed);
         QFile tmpFile(fileName);
         if (tmpFile.open(QFile::WriteOnly)) {
-            if(writeImage(&tmpFile, mimetype.toLatin1())) {
+            if (writeImage(&tmpFile, mimetype.toLatin1())) {
                 mTempFile = QUrl::fromLocalFile(tmpFile.fileName());
                 // try to make sure 3rd-party which gets the url of the temporary file e.g. on export
                 // properly treats this as readonly, also hide from other users
@@ -426,25 +411,26 @@ QUrl ExportManager::tempSave()
         }
     }
 
-    emit errorMessage(i18n("Cannot save screenshot. Error while writing temporary local file."));
+    Q_EMIT errorMessage(i18n("Cannot save screenshot. Error while writing temporary local file."));
     return QUrl();
 }
 
 bool ExportManager::save(const QUrl &url)
 {
     if (!(url.isValid())) {
-        emit errorMessage(i18n("Cannot save screenshot. The save filename is invalid."));
+        Q_EMIT errorMessage(i18n("Cannot save screenshot. The save filename is invalid."));
         return false;
     }
 
-    QString mimetype = makeSaveMimetype(url);
+    const QString mimetype = makeSaveMimetype(url);
     bool saveSucceded = false;
     if (url.isLocalFile()) {
-         saveSucceded = localSave(url, mimetype);
+        saveSucceded = localSave(url, mimetype);
     } else {
         saveSucceded = remoteSave(url, mimetype);
     }
     if (saveSucceded) {
+        mImageSavedNotInTemp = true;
         KRecentDocument::add(url, QGuiApplication::desktopFileName());
     }
     return saveSucceded;
@@ -455,13 +441,18 @@ bool ExportManager::isFileExists(const QUrl &url) const
     if (!(url.isValid())) {
         return false;
     }
-    KIO::StatJob * existsJob = KIO::statDetails(url, KIO::StatJob::DestinationSide, KIO::StatNoDetails, KIO::HideProgressInfo);
+    KIO::StatJob *existsJob = KIO::statDetails(url, KIO::StatJob::DestinationSide, KIO::StatNoDetails, KIO::HideProgressInfo);
 
     existsJob->exec();
 
     return (existsJob->error() == KJob::NoError);
 }
 
+bool ExportManager::isImageSavedNotInTemp() const
+{
+    return mImageSavedNotInTemp;
+}
+
 bool ExportManager::isTempFileAlreadyUsed(const QUrl &url) const
 {
     return mUsedTempFileNames.contains(url);
@@ -472,7 +463,7 @@ bool ExportManager::isTempFileAlreadyUsed(const QUrl &url) const
 void ExportManager::doSave(const QUrl &url, bool notify)
 {
     if (mSavePixmap.isNull()) {
-        emit errorMessage(i18n("Cannot save an empty screenshot image."));
+        Q_EMIT errorMessage(i18n("Cannot save an empty screenshot image."));
         return;
     }
 
@@ -481,9 +472,9 @@ void ExportManager::doSave(const QUrl &url, bool notify)
         QDir dir(savePath.path());
         dir.cdUp();
 
-        emit imageSaved(savePath);
+        Q_EMIT imageSaved(savePath);
         if (notify) {
-            emit forceNotify(savePath);
+            Q_EMIT forceNotify(savePath);
         }
     }
 }
@@ -494,6 +485,7 @@ bool ExportManager::doSaveAs(QWidget *parentWindow, bool notify)
 
     // construct the supported mimetype list
     const auto mimeTypes = QImageWriter::supportedMimeTypes();
+    supportedFilters.reserve(mimeTypes.count());
     for (const auto &mimeType : mimeTypes) {
         supportedFilters.append(QString::fromUtf8(mimeType).trimmed());
     }
@@ -515,10 +507,10 @@ bool ExportManager::doSaveAs(QWidget *parentWindow, bool notify)
         const QUrl saveUrl = dialog.selectedUrls().constFirst();
         if (saveUrl.isValid()) {
             if (save(saveUrl)) {
-                emit imageSaved(saveUrl);
+                Q_EMIT imageSaved(saveUrl);
                 Settings::setLastSaveAsLocation(saveUrl);
                 if (notify) {
-                    emit forceNotify(saveUrl);
+                    Q_EMIT forceNotify(saveUrl);
                 }
                 return true;
             }
@@ -530,7 +522,7 @@ bool ExportManager::doSaveAs(QWidget *parentWindow, bool notify)
 void ExportManager::doSaveAndCopy(const QUrl &url)
 {
     if (mSavePixmap.isNull()) {
-        emit errorMessage(i18n("Cannot save an empty screenshot image."));
+        Q_EMIT errorMessage(i18n("Cannot save an empty screenshot image."));
         return;
     }
 
@@ -538,10 +530,9 @@ void ExportManager::doSaveAndCopy(const QUrl &url)
     if (save(savePath)) {
         QDir dir(savePath.path());
         dir.cdUp();
-        Settings::setLastSaveLocation(savePath);
 
         doCopyToClipboard(false);
-        emit imageSavedAndCopied(savePath);
+        Q_EMIT imageSavedAndCopied(savePath);
     }
 }
 
@@ -551,10 +542,30 @@ void ExportManager::doCopyToClipboard(bool notify)
     auto data = new QMimeData();
     data->setImageData(mSavePixmap.toImage());
     data->setData(QStringLiteral("x-kde-force-image-copy"), QByteArray());
-    QApplication::clipboard()->setMimeData(data, QClipboard::Clipboard);
-    emit imageCopied();
+    KSystemClipboard::instance()->setMimeData(data, QClipboard::Clipboard);
+    Q_EMIT imageCopied();
     if (notify) {
-        emit forceNotify(QUrl());
+        Q_EMIT forceNotify(QUrl());
+    }
+}
+
+void ExportManager::doCopyLocationToClipboard(bool notify)
+{
+    QString localFile;
+    if (mImageSavedNotInTemp) {
+        // The image has been saved (manually or automatically), we need to choose that file path
+        localFile = Settings::self()->lastSaveLocation().toLocalFile();
+    } else {
+        // use a temporary save path, and copy that to clipboard instead
+        localFile = ExportManager::instance()->tempSave().toLocalFile();
+    }
+
+    auto data = new QMimeData();
+    data->setText(localFile);
+    KSystemClipboard::instance()->setMimeData(data, QClipboard::Clipboard);
+    Q_EMIT imageLocationCopied(QUrl::fromLocalFile(localFile));
+    if (notify) {
+        Q_EMIT forceNotify(QUrl::fromLocalFile(localFile));
     }
 }
 
@@ -563,7 +574,7 @@ void ExportManager::doPrint(QPrinter *printer)
     QPainter painter;
 
     if (!(painter.begin(printer))) {
-        emit errorMessage(i18n("Printing failed. The printer failed to initialize."));
+        Q_EMIT errorMessage(i18n("Printing failed. The printer failed to initialize."));
         delete printer;
         return;
     }
@@ -580,35 +591,17 @@ void ExportManager::doPrint(QPrinter *printer)
     return;
 }
 
-const QMap<QString, KLocalizedString> ExportManager::filenamePlaceholders {
-    {QStringLiteral("%Y"), ki18nc(
-            "A placeholder in the user configurable filename will replaced by the specified value",
-            "Year (4 digit)")},
-    {QStringLiteral("%y"), ki18nc(
-            "A placeholder in the user configurable filename will replaced by the specified value",
-            "Year (2 digit)")},
-    {QStringLiteral("%M"), ki18nc(
-            "A placeholder in the user configurable filename will replaced by the specified value",
-            "Month")},
-    {QStringLiteral("%D"), ki18nc(
-            "A placeholder in the user configurable filename will replaced by the specified value",
-            "Day")},
-    {QStringLiteral("%H"), ki18nc(
-            "A placeholder in the user configurable filename will replaced by the specified value",
-            "Hour")},
-    {QStringLiteral("%m"), ki18nc(
-            "A placeholder in the user configurable filename will replaced by the specified value",
-            "Minute")},
-    {QStringLiteral("%S"), ki18nc(
-            "A placeholder in the user configurable filename will replaced by the specified value",
-            "Second")},
-    {QStringLiteral("%T"), ki18nc(
-            "A placeholder in the user configurable filename will replaced by the specified value",
-            "Window Title")},
-    {QStringLiteral("%d"), ki18nc(
-            "A placeholder in the user configurable filename will replaced by the specified value",
-            "Sequential numbering")},
-    {QStringLiteral("%Nd"), ki18nc(
-            "A placeholder in the user configurable filename will replaced by the specified value",
-            "Sequential numbering, padded out to N digits")},
+const QMap<QString, KLocalizedString> ExportManager::filenamePlaceholders{
+    {QStringLiteral("%Y"), ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Year (4 digit)")},
+    {QStringLiteral("%y"), ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Year (2 digit)")},
+    {QStringLiteral("%M"), ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Month")},
+    {QStringLiteral("%D"), ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Day")},
+    {QStringLiteral("%H"), ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Hour")},
+    {QStringLiteral("%m"), ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Minute")},
+    {QStringLiteral("%S"), ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Second")},
+    {QStringLiteral("%t"), ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Timezone")},
+    {QStringLiteral("%T"), ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Window Title")},
+    {QStringLiteral("%d"), ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Sequential numbering")},
+    {QStringLiteral("%Nd"),
+     ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Sequential numbering, padded out to N digits")},
 };
