@@ -12,10 +12,6 @@
 #include "Config.h"
 #include "ExportManager.h"
 
-#ifdef KIPI_FOUND
-#include "KipiInterface/KSGKipiInterface.h"
-#endif
-
 #ifdef PURPOSE_FOUND
 #include <Purpose/AlternativesModel>
 #include <PurposeWidgets/Menu>
@@ -35,30 +31,20 @@ private Q_SLOTS:
 
 Q_SIGNALS:
 
-    void imageShared(bool error, const QString &message);
+    void imageShared(int error, const QString &message);
 
 private:
     void getKServiceItems();
 
-#ifdef KIPI_FOUND
-    void getKipiItems();
-    void loadKipiItems();
-
-    bool mKipiMenuLoaded;
-    QMenu *mKipiMenu;
-    KSGKipiInterface *mKipiInterface;
-    QWidget mDummyWidget;
-#endif
-
 #ifdef PURPOSE_FOUND
     void loadPurposeMenu();
     void loadPurposeItems();
 
     bool mUpdatedImageAvailable;
-    Purpose::Menu *mPurposeMenu;
+    Purpose::Menu *mPurposeMenu = nullptr;
 #endif
 
-    ExportManager *mExportManager;
+    ExportManager *const mExportManager;
 };
 
 #endif // EXPORTMENU_H
