@@ -20,14 +20,22 @@
 #include <QKeyEvent>
 #include <QPainter>
 #include <QPrintDialog>
+#include <QPrinter>
+#include <QPropertyAnimation>
 #include <QPushButton>
+#include <QScreen>
+#include <QStyle>
 #include <QTimer>
 #include <QVBoxLayout>
 #include <QVariantAnimation>
 #include <QtMath>
 
 #ifdef XCB_FOUND
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <QX11Info>
+#else
+#include <private/qtx11extras_p.h>
+#endif
 #include <xcb/xcb.h>
 #endif
 
@@ -35,7 +43,12 @@
 #include <KConfigGroup>
 #include <KGuiItem>
 #include <KHelpMenu>
+#include <kio_version.h>
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+#include <KIO/JobUiDelegateFactory>
+#else
 #include <KIO/JobUiDelegate>
+#endif
 #include <KIO/OpenFileManagerWindowJob>
 #include <KIO/OpenUrlJob>
 #include <KLocalizedString>
@@ -61,8 +74,6 @@ KSMainWindow::KSMainWindow(Platform::GrabModes theGrabModes, Platform::ShutterMo
     , mClipboardImageAction(new QAction(this))
     , mSaveButton(new QToolButton(this))
     , mSaveMenu(new QMenu(this))
-    , mSaveAsAction(new QAction(this))
-    , mSaveAction(new QAction(this))
     , mMessageWidget(new KMessageWidget(this))
     , mToolsMenu(new QMenu(this))
     , mScreenRecorderToolsMenu(new QMenu(this))
@@ -146,24 +157,8 @@ void KSMainWindow::init()
     mAnnotateButton->setText(i18n("Annotate"));
     mAnnotateButton->setToolTip(i18n("Add annotation to the screenshot"));
     mAnnotateButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
-    mAnnotateButton->setIcon(QIcon::fromTheme(QStringLiteral("document-edit")));
-    connect(mAnnotateButton, &QToolButton::clicked, this, [this] {
-        if (mAnnotatorActive) {
-            mKSWidget->hideAnnotator();
-            mAnnotateButton->setText(i18n("Annotate"));
-        } else {
-            mKSWidget->showAnnotator();
-            mAnnotateButton->setText(i18n("Annotation done"));
-        }
-
-        mToolsButton->setEnabled(mAnnotatorActive);
-        mSendToButton->setEnabled(mAnnotatorActive);
-        mClipboardButton->setEnabled(mAnnotatorActive);
-        mSaveButton->setEnabled(mAnnotatorActive);
-
-        mAnnotatorActive = !mAnnotatorActive;
-    });
-
+    mAnnotateButton->setIcon(QIcon::fromTheme(QStringLiteral("edit-image"), QIcon::fromTheme(QStringLiteral("document-edit"))));
+    connect(mAnnotateButton, &QToolButton::clicked, this, &KSMainWindow::updateAnnotatorVisibility);
     mDialogButtonBox->addButton(mAnnotateButton, QDialogButtonBox::ActionRole);
 #endif
 
@@ -270,9 +265,11 @@ void KSMainWindow::init()
     });
 
     mHideMessageWidgetTimer = new QTimer(this);
-    //     connect(mHideMessageWidgetTimer, &QTimer::timeout,
-    //             mMessageWidget, &KMessageWidget::animatedHide);
     mHideMessageWidgetTimer->setInterval(10000);
+    mHideMessageWidgetTimer->setSingleShot(true);
+    connect(mKSWidget, &KSWidget::screenshotPixmapSet, mMessageWidget, &KMessageWidget::animatedHide);
+    connect(mHideMessageWidgetTimer, &QTimer::timeout, mMessageWidget, &KMessageWidget::animatedHide);
+
     // done with the init
 }
 
@@ -341,7 +338,7 @@ void KSMainWindow::moveEvent(QMoveEvent *event)
 // slots
 void KSMainWindow::captureScreenshot(Spectacle::CaptureMode theCaptureMode, int theTimeout, bool theIncludePointer, bool theIncludeDecorations)
 {
-    if (theTimeout < 0) { // OnClick is checked (always the case on Wayland)
+    if (theTimeout <= 0) { // OnClick is checked (always the case on Wayland)
         hide();
         Q_EMIT newScreenshotRequest(theCaptureMode, theTimeout, theIncludePointer, theIncludeDecorations);
         return;
@@ -389,7 +386,7 @@ void KSMainWindow::captureScreenshot(Spectacle::CaptureMode theCaptureMode, int
     delayAnimation->start();
 }
 
-void KSMainWindow::setScreenshotAndShow(const QPixmap &pixmap)
+void KSMainWindow::setScreenshotAndShow(const QPixmap &pixmap, bool showAnnotator)
 {
     mPixmapExists = !pixmap.isNull();
     if (mPixmapExists) {
@@ -399,6 +396,10 @@ void KSMainWindow::setScreenshotAndShow(const QPixmap &pixmap)
         setWindowModified(true);
     } else {
         restoreWindowTitle();
+        // check if there is an screenshot already visible, if true, don't disable buttons
+        // this check has to be done after if (mPixmapExists), otherwise it
+        // might set a new empty screenshot, overwriting the previous one
+        mPixmapExists = mKSWidget->isScreenshotSet();
     }
 
 #ifdef KIMAGEANNOTATOR_FOUND
@@ -416,6 +417,11 @@ void KSMainWindow::setScreenshotAndShow(const QPixmap &pixmap)
     if (mPixmapExists) {
         resize(QSize(windowWidth(pixmap), DEFAULT_WINDOW_HEIGHT));
     }
+    if (showAnnotator) {
+#ifdef KIMAGEANNOTATOR_FOUND
+        mAnnotateButton->click();
+#endif
+    }
 }
 
 void KSMainWindow::showPrintDialog()
@@ -432,7 +438,11 @@ void KSMainWindow::showPrintDialog()
 void KSMainWindow::openScreenshotsFolder()
 {
     auto job = new KIO::OpenUrlJob(Settings::defaultSaveLocation());
-    job->setUiDelegate(new KIO::JobUiDelegate(KIO::JobUiDelegate::AutoHandlingEnabled, this));
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+    job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+#else
+    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+#endif
     job->start();
 }
 
@@ -485,7 +495,7 @@ void KSMainWindow::showInlineMessage(const QString &message,
     }
 }
 
-void KSMainWindow::showImageSharedFeedback(bool error, const QString &message)
+void KSMainWindow::showImageSharedFeedback(int error, const QString &message)
 {
     if (error == 1) {
         // error == 1 means the user cancelled the sharing
@@ -540,7 +550,7 @@ void KSMainWindow::imageSavedAndLocationCopied(const QUrl &location)
     showInlineMessage(
         i18n("The screenshot has been saved as <a href=\"%1\">%2</a> and its location has been copied to clipboard", location.toString(), location.fileName()),
         KMessageWidget::Positive,
-        MessageDuration::AutoHide,
+        MessageDuration::Persistent,
         {mOpenContaining});
 }
 
@@ -575,7 +585,7 @@ void KSMainWindow::imageSaved(const QUrl &location)
     setWindowModified(false);
     showInlineMessage(i18n("The screenshot was saved as <a href=\"%1\">%2</a>", location.toString(), location.fileName()),
                       KMessageWidget::Positive,
-                      MessageDuration::AutoHide,
+                      MessageDuration::Persistent,
                       {mOpenContaining});
 }
 
@@ -585,7 +595,7 @@ void KSMainWindow::imageSavedAndCopied(const QUrl &location)
     setWindowModified(false);
     showInlineMessage(i18n("The screenshot was copied to the clipboard and saved as <a href=\"%1\">%2</a>", location.toString(), location.fileName()),
                       KMessageWidget::Positive,
-                      MessageDuration::AutoHide,
+                      MessageDuration::Persistent,
                       {mOpenContaining});
 }
 
@@ -647,5 +657,58 @@ void KSMainWindow::keyPressEvent(QKeyEvent *event)
             return;
         }
     }
+#ifdef KIMAGEANNOTATOR_FOUND
+    if (event->key() == Qt::Key_Escape) {
+        if (mAnnotatorActive) {
+            updateAnnotatorVisibility();
+            return;
+        }
+    }
+#endif
     QDialog::keyPressEvent(event);
 }
+
+#ifdef KIMAGEANNOTATOR_FOUND
+void KSMainWindow::updateAnnotatorVisibility()
+{
+    static QSize oldSize = size();
+    QScreen *screen = QGuiApplication::primaryScreen();
+
+    // animation required for non-maximized resizing
+    QPropertyAnimation *resizeAnimation = new QPropertyAnimation(this, "size");
+    auto kdeGlobalsConfig = KConfigGroup(KSharedConfig::openConfig(), QStringLiteral("KDE"));
+    float animationDurationFactor = std::max(0.0, kdeGlobalsConfig.readEntry("AnimationDurationFactor", 1.0));
+
+    resizeAnimation->setDuration(2 * style()->styleHint(QStyle::SH_Widget_Animation_Duration, nullptr, this) * animationDurationFactor);
+
+    if (mAnnotatorActive) {
+        mKSWidget->hideAnnotator();
+        if (windowState() == Qt::WindowMaximized) {
+            showNormal();
+        } else {
+            resizeAnimation->setEndValue(oldSize);
+            resizeAnimation->start();
+        }
+        mAnnotateButton->setText(i18nc("@action:button", "Annotate"));
+    } else {
+        mKSWidget->showAnnotator();
+        const auto sizeWhenAnnotating = mKSWidget->sizeHintWhenAnnotating();
+
+        if (KWindowSystem::isPlatformWayland() || screen->availableSize().height() <= sizeWhenAnnotating.height()
+            || screen->availableSize().width() <= sizeWhenAnnotating.width()) {
+            showMaximized();
+        } else {
+            resizeAnimation->setEndValue(sizeWhenAnnotating);
+            resizeAnimation->start();
+        }
+        mAnnotateButton->setText(i18nc("@action:button", "Annotation Done"));
+    }
+
+    mToolsButton->setEnabled(mAnnotatorActive);
+    mSendToButton->setEnabled(mAnnotatorActive);
+    mClipboardButton->setEnabled(mAnnotatorActive);
+    mSaveButton->setEnabled(mAnnotatorActive);
+
+    mAnnotatorActive = !mAnnotatorActive;
+}
+#endif
