@@ -8,6 +8,7 @@
 #include "KSWidget.h"
 #include "spectacle_gui_debug.h"
 
+#include "CaptureAreaComboBox.h"
 #include "ExportManager.h"
 #include "KSImageWidget.h"
 #include "ProgressButton.h"
@@ -30,49 +31,22 @@
 
 #include <KConfigDialogManager>
 #include <KLocalizedString>
+#include <QGraphicsOpacityEffect>
 
 KSWidget::KSWidget(Platform::GrabModes theGrabModes, QWidget *parent)
     : QWidget(parent)
+    , mImageWidget(new KSImageWidget(this))
 {
     mStack = new QStackedLayout(this);
 
     // we'll init the widget that holds the image first
-    mImageWidget = new KSImageWidget(this);
     mImageWidget->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     connect(mImageWidget, &KSImageWidget::dragInitiated, this, &KSWidget::dragInitiated);
 
-#ifdef KIMAGEANNOTATOR_FOUND
-    mAnnotator = new kImageAnnotator::KImageAnnotator();
-    mAnnotator->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-    mAnnotator->setCanvasColor(QColor(255, 255, 255, 0));
-    mStack->addWidget(mAnnotator);
-#endif
-
     // the capture mode options first
     mCaptureModeLabel = new QLabel(i18n("<b>Capture Mode</b>"), this);
-    mCaptureArea = new QComboBox(this);
+    mCaptureArea = new CaptureAreaComboBox(theGrabModes, this);
 
-    if (theGrabModes.testFlag(Platform::GrabMode::AllScreens)) {
-        QString lFullScreenLabel = QApplication::screens().count() == 1 ? i18n("Full Screen") : i18n("Full Screen (All Monitors)");
-
-        mCaptureArea->insertItem(0, lFullScreenLabel, Spectacle::CaptureMode::AllScreens);
-    }
-    if (theGrabModes.testFlag(Platform::GrabMode::AllScreensScaled) && QApplication::screens().count() > 1) {
-        QString lFullScreenLabel = i18n("Full Screen (All Monitors, scaled)");
-        mCaptureArea->insertItem(1, lFullScreenLabel, Spectacle::CaptureMode::AllScreensScaled);
-    }
-    if (theGrabModes.testFlag(Platform::GrabMode::PerScreenImageNative)) {
-        mCaptureArea->insertItem(2, i18n("Rectangular Region"), Spectacle::CaptureMode::RectangularRegion);
-    }
-    if (theGrabModes.testFlag(Platform::GrabMode::CurrentScreen)) {
-        mCaptureArea->insertItem(3, i18n("Current Screen"), Spectacle::CaptureMode::CurrentScreen);
-    }
-    if (theGrabModes.testFlag(Platform::GrabMode::ActiveWindow)) {
-        mCaptureArea->insertItem(4, i18n("Active Window"), Spectacle::CaptureMode::ActiveWindow);
-    }
-    if (theGrabModes.testFlag(Platform::GrabMode::WindowUnderCursor)) {
-        mCaptureArea->insertItem(5, i18n("Window Under Cursor"), Spectacle::CaptureMode::WindowUnderCursor);
-    }
     if (theGrabModes.testFlag(Platform::GrabMode::TransientWithParent)) {
         mTransientWithParentAvailable = true;
     }
@@ -197,10 +171,6 @@ KSWidget::KSWidget(Platform::GrabModes theGrabModes, QWidget *parent)
     placeHolder->setLayout(mMainLayout);
 
     mStack->addWidget(placeHolder);
-
-#ifdef KIMAGEANNOTATOR_FOUND
-    mStack->addWidget(mAnnotator);
-#endif
 }
 
 int KSWidget::imagePaddingWidth() const
@@ -219,7 +189,7 @@ int KSWidget::imagePaddingWidth() const
     return lPaddingWidth;
 }
 
-bool KSWidget::isScreenshotSet()
+bool KSWidget::isScreenshotSet() const
 {
     return mImageWidget->isPixmapSet();
 }
@@ -240,6 +210,7 @@ void KSWidget::setScreenshotPixmap(const QPixmap &thePixmap)
     }
     mImageWidget->show();
     mImageWidget->setScreenshot(thePixmap);
+    Q_EMIT screenshotPixmapSet();
 }
 
 void KSWidget::lockOnClickEnabled()
@@ -261,7 +232,7 @@ void KSWidget::lockOnClickDisabled()
 void KSWidget::newScreenshotClicked()
 {
     int lDelay = mCaptureOnClick->isChecked() ? -1 : (mDelayMsec->value() * 1000);
-    auto lMode = static_cast<Spectacle::CaptureMode>(mCaptureArea->currentData().toInt());
+    auto lMode = mCaptureArea->currentCaptureMode();
     if (mTransientWithParentAvailable && lMode == Spectacle::CaptureMode::WindowUnderCursor && !(mCaptureTransientOnly->isChecked())) {
         lMode = Spectacle::CaptureMode::TransientWithParent;
     }
@@ -280,7 +251,7 @@ void KSWidget::onClickStateChanged(int theState)
 
 void KSWidget::captureModeChanged(int theIndex)
 {
-    Spectacle::CaptureMode captureMode = static_cast<Spectacle::CaptureMode>(mCaptureArea->itemData(theIndex).toInt());
+    auto captureMode = mCaptureArea->captureModeForIndex(theIndex);
     switch (captureMode) {
     case Spectacle::CaptureMode::WindowUnderCursor:
         mWindowDecorations->setEnabled(true);
@@ -332,6 +303,18 @@ void KSWidget::setProgress(double progress)
 #ifdef KIMAGEANNOTATOR_FOUND
 void KSWidget::showAnnotator()
 {
+    if (!mAnnotator) {
+        mAnnotator = new kImageAnnotator::KImageAnnotator();
+        mAnnotator->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+        mAnnotator->setCanvasColor(QColor(255, 255, 255, 0));
+        mAnnotator->setSaveToolSelection(true);
+#ifdef KIMAGEANNOTATOR_HAS_EXTRA_TOOLS
+        mAnnotator->setControlsWidgetVisible(true);
+#endif
+
+        mStack->addWidget(mAnnotator);
+    }
+
     mStack->setCurrentIndex(1);
     QPixmap px = ExportManager::instance()->pixmap();
     px.setDevicePixelRatio(qApp->devicePixelRatio());
@@ -340,10 +323,41 @@ void KSWidget::showAnnotator()
 
 void KSWidget::hideAnnotator()
 {
+    if (!mAnnotator) {
+        return;
+    }
+
     mStack->setCurrentIndex(0);
     QImage image = mAnnotator->image();
     QPixmap px = QPixmap::fromImage(image);
     setScreenshotPixmap(px);
     ExportManager::instance()->setPixmap(px);
 }
+
+QSize KSWidget::sizeHintWhenAnnotating()
+{
+    if (!mAnnotator) {
+        return QSize();
+    }
+
+    /*
+     * when using Wayland only maximization shall be used and return value ignored.
+     * We return it anyway for other possible use-cases.
+     * Reason: Wayland doesn't allow moving of the window hence a too big window
+     * of spectacle would 'overflow' outside the display.
+     */
+
+#ifdef KIMAGEANNOTATOR_HAS_FIXED_SIZEHINT
+    return mAnnotator->sizeHint();
+#endif
+
+    if (qApp->devicePixelRatio() == 1) {
+        return mAnnotator->sizeHint();
+    } else {
+        // if scaling is >100%, than `image().size() > sizeHint()` calculates an bigger value
+        // unless KIMAGEANNOTATOR_HAS_FIXED_SIZEHINT is set
+        return mAnnotator->image().size();
+    }
+}
+
 #endif
