@@ -29,8 +29,9 @@ int main(int argc, char **argv)
     // set up the application
 
     QCoreApplication::setAttribute(Qt::AA_DontCreateNativeWidgetSiblings);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-
+#endif
     QApplication app(argc, argv);
 
     KLocalizedString::setApplicationDomain("spectacle");
@@ -57,9 +58,9 @@ int main(int argc, char **argv)
     // first parsing for help-about
     lCmdLineParser.process(app.arguments());
     aboutData.processCommandLine(&lCmdLineParser);
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QGuiApplication::setFallbackSessionManagementEnabled(false);
-
+#endif
     auto disableSessionManagement = [](QSessionManager &sm) {
         sm.setRestartHint(QSessionManager::RestartNever);
     };
@@ -70,6 +71,7 @@ int main(int argc, char **argv)
     if (lCmdLineParser.isSet(QStringLiteral("new-instance"))) {
         lCore.init();
 
+        QObject::connect(qApp, &QApplication::aboutToQuit, Settings::self(), &Settings::save);
         QObject::connect(&lCore, &SpectacleCore::allDone, &app, &QCoreApplication::quit, Qt::QueuedConnection);
 
         // fire it up
