@@ -5,7 +5,7 @@
 
 #pragma once
 
-#include <QCommandLineParser>
+class QCommandLineParser;
 #include <QObject>
 
 #include "ExportManager.h"
@@ -84,6 +84,8 @@ private:
     bool mCopyImageToClipboard;
     bool mCopyLocationToClipboard;
     bool mSaveToOutput;
+    bool mEditExisting;
+    bool mExistingLoaded;
 
     KWayland::Client::PlasmaShell *mWaylandPlasmashell = nullptr;
 };
